/**
 * @category Summit
 * @package Summit\Checkout
 * @copyright Copyright (c) 2016 Summit Media Limited (http://www.summit.co.uk/)
 * @license http://opensource.org/licenses/afl-3.0.php Academic Free License (AFL 3.0)
 */
define([
    'Magento_Checkout/js/view/summary/grand-total',
    'Magento_Checkout/js/model/quote',
    'Magento_Checkout/js/model/totals',
    'Magento_Checkout/js/model/step-navigator'
], function (Component, quote, totals, stepNavigator) {
    'use strict';

    return Component.extend({
        defaults: {
            template: 'Dexanet_AwesomeCheckout/summary/grand-total'
        },
        totals: quote.getTotals(),
        getValue: function () {
            var price = 0;
            if (this.totals()) {
                price = totals.getSegment('grand_total').value;
            }

            // Default Magento doesn't show shipping cost before payment step
            if (!stepNavigator.isProcessed('shipping')) {
                if (!!this.getQuoteShippingValue()) {
                    //Update grand totals when new shipping method is selected
                    if (this.getQuoteShippingValue() !== this.getSelectedShippingValue()) {
                        price = parseFloat(price) - this.getQuoteShippingValue() + this.getSelectedShippingValue();
                    }
                } else {
                    price = parseFloat(price) + this.getSelectedShippingValue();
                }
            }

            return this.getFormattedPrice(price);
        },
        /**
         * @returns {Boolean}
         */
        isShippingCalculated: function () {
            var summaryShipping = totals.getSegment('shipping').value;
            if (summaryShipping > 0) {
                return null !== quote.shippingMethod();
            } else {
                return this.totals() && totals.totals() && null !== quote.shippingMethod();
            }
        },
        /**
         * @returns {Number}
         */
        getSelectedShippingValue: function () {
            var price = 0;

            if (!quote.isVirtual()) {
                if (this.isShippingCalculated()) {
                    var shippingMethod = quote.shippingMethod();

                    if (shippingMethod) {
                        price = shippingMethod.amount;
                    } else {
                        price = this.totals().shipping_amount;
                    }
                } else if (typeof window.checkoutConfig.defaultDeliveryCost !== 'undefined') {
                    price = window.checkoutConfig.defaultDeliveryCost;
                }
            }

            return parseFloat(price);
        },
        /**
         * @returns {Number}
         */
        getQuoteShippingValue: function () {
            return quote.isVirtual() ? 0 : parseFloat(this.totals().shipping_incl_tax);
        }
    });
});