define(
    [
        'jquery',
        'ko',
        'uiComponent',
        'underscore',
        'Magento_Checkout/js/model/step-navigator',
        'Magento_Checkout/js/model/quote',
        'Magento_Customer/js/action/check-email-availability',
        'mage/translate'
    ],
    function (
        $,
        ko,
        Component,
        _,
        stepNavigator,
        quote,
        checkEmailAvailability,
        t
    ) {
        'use strict';

        return Component.extend({
            defaults: {
                template: 'Dexanet_AwesomeCheckout/login'
            },

            //add here your logic to display step,
            isVisible: ko.observable(!window.isCustomerLoggedIn),

            /**
             *
             * @returns {*}
             */
            initialize: function () {
                this._super();

                if (!window.isCustomerLoggedIn) {
                    stepNavigator.registerStep(
                        'login',
                        null,
                        t("Welcome"),
                        this.isVisible,
                        _.bind(this.navigate, this),

                        /**
                         * sort order value
                         * 'sort order value' < 10: step displays before shipping step;
                         * 10 < 'sort order value' < 20 : step displays between shipping and payment step
                         * 'sort order value' > 20 : step displays after payment step
                         */
                        0
                    );
                }

                return this;
            },

            /**
             * The navigate() method is responsible for navigation between checkout step
             * during checkout. You can add custom logic, for example some conditions
             * for switching to your custom step
             */
            navigate: function (step) {
                step && step.isVisible(true);
            },

            /**
             * @returns void
             */
            navigateToNextStep: function () {
                var loginFormSelector = 'form[data-role=email-with-possible-login]',
                    loginForm = $(loginFormSelector);

                if (loginForm.validation() && loginForm.validation('isValid')) {
                    if ($('input#has_password').is(':checked')) {
                        $('.action.login').click();
                    } else {
                        if (quote.guestEmail) {
                            checkEmailAvailability($.Deferred(), quote.guestEmail);
                        }

                        stepNavigator.next();
                    }
                }
            }
        });
    }
);